;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "darktooth-theme" "20251019.304"
  "From the darkness... it watches."
  '((emacs      "27.1")
    (autothemer "0.2"))
  :url "http://github.com/emacsfodder/emacs-theme-darktooth"
  :commit "998639b2ce629dbdc0901ed560371f82de7af490"
  :revdesc "998639b2ce62")
